=======
Credits
=======

Development Lead
----------------

* Ricardo Bánffy <rbanffy@gmail.com>
* Luke Skibinski https://github.com/lsh-0
* Piotr Surowiec https://github.com/Agrendalath

Contributors
------------

None yet. Why not be the first?
